"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { Tag } = req.ctx;
    const wiki = req.query.wiki;
    const tags = Array.isArray(req.query.tag) ? req.query.tag : [req.query.tag];
    if (wiki && tags) {
        try {
            const pageTags = yield Tag.query()
                .where('tags.branchName', wiki)
                .whereIn('tags.name', tags)
                .withGraphJoined('pages.[currentRevision, tags]');
            const pages = {};
            for (const tag of pageTags) {
                for (const page of tag.pages) {
                    if (pages[page.name]) {
                        pages[page.name].matchedTags++;
                    }
                    else {
                        pages[page.name] = {
                            id: page.id,
                            name: page.name,
                            title: page.currentRevision.title,
                            all_tags: page.tags.map((t) => t.name),
                            matchedTags: 1,
                        };
                    }
                }
            }
            const pagesList = Object.keys(pages)
                .reduce((acc, current) => acc.concat(pages[current]), [])
                .filter((page) => page.matchedTags === tags.length);
            res.send(pagesList);
        }
        catch (error) {
            res.status(500).send('Unhandled internal error, incident reported');
            req.ctx.reportError('Unhandled error', error);
        }
    }
    else {
        res.status(400).send({ error: 'Wiki or tags are not specified' });
    }
});
//# sourceMappingURL=tags-search.js.map