"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initRoutes = void 0;
const objection_1 = require("objection");
function initRoutes(app, routes) {
    routes.forEach((route) => {
        const method = route.method || 'get';
        // eslint-disable-next-line security/detect-non-literal-require, global-require, @typescript-eslint/no-var-requires
        const routeHandler = require(`../../controllers/${route.name}`).default;
        function routeInfoMiddleware(req, res, next) {
            req.routeInfo = route;
            next();
        }
        const routeMiddleware = [routeInfoMiddleware];
        app[method](route.path, routeMiddleware, (req, res, next) => {
            Promise.resolve(routeHandler(req, res)).catch((error) => {
                if (error instanceof objection_1.ValidationError) {
                    return res.status(400).send({ error: 'Validation error', details: error.data });
                }
                return next(error);
            });
        });
    });
}
exports.initRoutes = initRoutes;
//# sourceMappingURL=router.js.map