"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Context = exports.sentry = void 0;
const Sentry = __importStar(require("@sentry/node"));
const pino_1 = require("./pino");
const worker_1 = require("./worker");
const wikidot_kit_1 = __importDefault(require("wikidot-kit"));
const models_1 = require("../models");
exports.sentry = Sentry;
exports.sentry.init({ dsn: process.env.SENTRY_DSN });
const devMode = Boolean(process.env.DEV_MODE);
let config;
function serializeError(error) {
    return error.stack ? error.stack : error.message;
}
class Context {
    constructor(name, tags, parent, logger) {
        this.name = name;
        this.tags = tags;
        if (parent) {
            this.parent = parent;
        }
        this.logger = logger || pino_1.baseLogger;
        this.loggerPrefix = parent ? `${parent.loggerPrefix} [${name}]`.trim() + ' ' : '';
        this.wk = new wikidot_kit_1.default(this.config.wikidotApiToken, (message, type, extra) => {
            if (type === 'info') {
                this.log(message, extra);
            }
            else {
                this.logError(message);
            }
        });
    }
    static setAppConfig(appConfig) {
        config = appConfig;
    }
    log(message, extra) {
        if (extra) {
            this.logger.info(extra, this.loggerPrefix + message);
        }
        else {
            this.logger.info(this.loggerPrefix + message);
        }
    }
    logError(message, error, extra) {
        if (error) {
            if (extra) {
                this.logger.error({ error: serializeError(error), extra }, this.loggerPrefix + message);
            }
            else {
                this.logger.error({ error: serializeError(error) }, this.loggerPrefix + message);
            }
        }
        else {
            this.logger.error(this.loggerPrefix + message);
        }
    }
    reportError(message, error, extra) {
        this.logError(message, error, extra);
        exports.sentry.captureException(error, {
            tags: this.tags,
            extra: extra,
        });
    }
    create(name, tags) {
        return new Context(name, tags || {}, this);
    }
    setTag(name, value) {
        this.tags[name] = value.toString();
    }
    enqueue(task, args, queue = 'common'
    // TODO use some type instead of string
    ) {
        return __awaiter(this, void 0, void 0, function* () {
            yield worker_1.bossReady;
            return worker_1.boss.publish(queue, { task, args }, { retryLimit: 2 });
        });
    }
    batchedEnqueue(tasks, queue = 'common') {
        return tasks.map(({ task, args }) => this.enqueue(task, args, queue));
    }
    get config() {
        return config;
    }
    get devMode() {
        return devMode;
    }
    /* eslint-disable @typescript-eslint/explicit-module-boundary-types */
    get db() {
        return models_1.db;
    }
    get Draft() {
        return models_1.Draft;
    }
    get Page() {
        return models_1.Page;
    }
    get PageRevision() {
        return models_1.PageRevision;
    }
    get PageTag() {
        return models_1.PageTag;
    }
    get PageComment() {
        return models_1.PageComment;
    }
    get Branch() {
        return models_1.Branch;
    }
    get User() {
        return models_1.User;
    }
    get Tag() {
        return models_1.Tag;
    }
    get UserMembership() {
        return models_1.UserMembership;
    }
}
exports.Context = Context;
//# sourceMappingURL=utils.js.map