"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.scheduleTask = void 0;
function scheduleTask(appCtx, queueName, taskName, taskArguments) {
    const ctx = appCtx.create('scheduler');
    if (!ctx.config.queues.find((queue) => queue.name === queueName)) {
        throw new Error(`Unknown queue "${queueName}"`);
    }
    ctx.log(`Trying to schedule task ${taskName} in queue ${queueName} with args ${JSON.stringify(taskArguments)}`);
    ctx.enqueue(taskName, taskArguments, queueName)
        .then(() => {
        ctx.log(`Task ${taskName} scheduled in queue ${queueName} with args ${JSON.stringify(taskArguments)}`);
    })
        .catch((error) => {
        ctx.reportError(`Task ${taskName} scheduling has failed`, error, {
            taskName,
            taskArguments,
            queueName,
        });
    })
        .then(() => {
        // Give time to logger to write buffer (probably should use pino.flush here instead)
        setTimeout(() => {
            process.nextTick(() => process.exit());
        }, 10);
    });
}
exports.scheduleTask = scheduleTask;
//# sourceMappingURL=scheduler.js.map