"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const dotenv_1 = __importDefault(require("dotenv"));
dotenv_1.default.config();
const mode = process.argv[2] || 'dev';
var config_1 = require("./config");
Object.defineProperty(exports, "config", { enumerable: true, get: function () { return config_1.config; } });
const config_2 = require("./config");
var utils_1 = require("./core/utils");
Object.defineProperty(exports, "Context", { enumerable: true, get: function () { return utils_1.Context; } });
Object.defineProperty(exports, "sentry", { enumerable: true, get: function () { return utils_1.sentry; } });
const utils_2 = require("./core/utils");
utils_2.Context.setAppConfig(config_2.config);
const ctx = new utils_2.Context(mode, {});
const console_1 = __importDefault(require("./core/console"));
const express_1 = __importDefault(require("./core/express"));
const worker_1 = require("./core/worker");
const routes_1 = require("./routes");
const source_map_support_1 = __importDefault(require("source-map-support"));
source_map_support_1.default.install();
function runServer(cx) {
    const port = Number(process.env.PORT) || 4444;
    const listen = express_1.default(cx, routes_1.routes);
    listen(port);
    cx.log('[server] Server is listening');
}
switch (mode) {
    case 'dev':
        runServer(ctx);
        worker_1.runWorker(ctx);
        break;
    case 'server':
        runServer(ctx);
        break;
    case 'console':
        console_1.default(ctx).catch(console.error);
        break;
    case 'execute':
        worker_1.executeTask(ctx, process.argv[3], process.argv.slice(4), true).catch((error) => {
            ctx.logError('Task execution failed', error);
            process.nextTick(() => process.exit());
        });
        break;
    case 'worker':
        worker_1.runWorker(ctx);
        break;
    case 'schedule':
        worker_1.scheduleTask(ctx, process.argv[3], process.argv[4], process.argv.slice(5));
        break;
    default:
        throw new Error(`Unknown mode "${mode}"`);
}
//# sourceMappingURL=index.js.map