"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.User = void 0;
const _1 = require(".");
function prepareUsername(input) {
    return {
        displayUsername: input,
        username: input.toLowerCase().replace(/\s+/g, '-'),
    };
}
class User extends _1.Model {
    static upsert(tx, user) {
        const { username, displayUsername } = prepareUsername(user.username || '');
        user.displayUsername = displayUsername;
        user.username = username;
        const insert = _1.db(User.tableName).insert(user);
        const update = _1.db.queryBuilder().update(user);
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        return tx.raw('? ON CONFLICT (wikidot_uid) DO ? returning *', [insert, update]).get('rows').get(0);
    }
    static findOrCreateByGoogleId(googleId) {
        return __awaiter(this, void 0, void 0, function* () {
            const existingUser = yield User.query().select('*').where({ googleId }).first();
            if (existingUser) {
                return existingUser.id;
            }
            const newUser = yield User.query().insert({
                googleId,
            });
            return newUser.id;
        });
    }
    static fetchOrResolveByUid(ctx, wikiUrl, wikidotUid) {
        return __awaiter(this, void 0, void 0, function* () {
            const existingUser = yield User.query().findOne({ wikidotUid });
            if (existingUser) {
                return existingUser;
            }
            const user = yield ctx.wk.fetchUserProfile(wikiUrl, wikidotUid);
            const { username, displayUsername } = prepareUsername(user.username || '');
            return User.query()
                .insert({
                wikidotUid: user.uid,
                username,
                displayUsername,
                createdAt: user.userSince,
                about: user.about,
            })
                .returning('*');
        });
    }
}
exports.User = User;
User.tableName = 'users';
User.relationMappings = {
    branches: {
        relation: _1.Model.ManyToManyRelation,
        modelClass: 'branch',
        join: {
            from: 'users.id',
            through: {
                from: 'user_memberships.user_id',
                to: 'user_memberships.branch_name',
            },
            to: 'branches.name',
        },
    },
};
//# sourceMappingURL=user.js.map