"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.tetherAccount = exports.TetherResult = void 0;
const MIGRATION_WIKI_NAME = 'scp-migration';
const PAGE_NOT_FOUND_CODE = 406;
var TetherResult;
(function (TetherResult) {
    TetherResult["Ok"] = "Ok";
    TetherResult["PageNotFound"] = "PageNotFound";
    TetherResult["AlreadyTethered"] = "AlreadyTethered";
    TetherResult["WikidotUserAlreadyTethered"] = "WikidotUserAlreadyTethered";
})(TetherResult = exports.TetherResult || (exports.TetherResult = {}));
function tetherAccount(ctx, userId) {
    return __awaiter(this, void 0, void 0, function* () {
        const pageName = `scp-id-${userId}`;
        const { User } = ctx;
        try {
            const tetherPage = yield ctx.wk.fetchPage(MIGRATION_WIKI_NAME, pageName);
            const author = tetherPage.created_by;
            const user = yield User.query().select('*').where({ id: userId }).first();
            if (!user) {
                throw new Error('User not found');
            }
            if (user.wikidotUid) {
                return { result: TetherResult.AlreadyTethered };
            }
            const existingUser = yield User.query().select('*').where({ username: author }).first();
            if (existingUser && existingUser.wikidotUid) {
                // FIXME
                // Here we should do three things in a transaction:
                // - delete currently logged in account
                // - fill current google_id to that already existing wikidot account
                // - logout current user
                return { result: TetherResult.WikidotUserAlreadyTethered };
            }
            const wkUser = yield ctx.wk.fetchUserProfileByUsername(author);
            yield User.query()
                .update({
                displayUsername: author,
                username: author.toLowerCase(),
                wikidotUid: wkUser.uid,
                createdAt: wkUser.userSince,
            })
                .where({ id: userId });
            return { result: TetherResult.Ok };
        }
        catch (error) {
            if (error.code === PAGE_NOT_FOUND_CODE) {
                return { result: TetherResult.PageNotFound };
            }
            throw error;
        }
    });
}
exports.tetherAccount = tetherAccount;
//# sourceMappingURL=wikidot-tethering.service.js.map