"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
function run(ctx, branchName, uid) {
    return __awaiter(this, void 0, void 0, function* () {
        const { Branch, User, UserMembership } = ctx;
        const branch = yield Branch.query().where({ name: branchName }).first();
        if (!branch) {
            throw new Error(`Unknown site "${branchName}"`);
        }
        ctx.log(`Importing member ${uid} from ${branch.name}`);
        try {
            const user = yield User.fetchOrResolveByUid(ctx, branch.url, uid);
            const existingMembership = yield UserMembership.query().findOne({ userId: user.id, branchName });
            if (!existingMembership) {
                const userProfile = yield ctx.wk.fetchUserProfile(branch.url, uid);
                yield UserMembership.query().insert({
                    userId: user.id,
                    branchName,
                    createdAt: userProfile.memberSince,
                });
            }
            ctx.log('Imported user profile', user);
        }
        catch (error) {
            ctx.reportError('Error during member import', error, { uid });
        }
    });
}
exports.run = run;
//# sourceMappingURL=member-import.js.map