'use strict';

exports.up = (knex) =>
    knex.raw(`
    CREATE SEQUENCE counter_seq;

    CREATE OR REPLACE FUNCTION get_id(OUT result bigint) AS $$
    DECLARE
        our_epoch bigint := 1514754000000;
        seq_id bigint;
        now_millis bigint;
        shard_id int := 1;
    BEGIN
        SELECT nextval('counter_seq') % 4096 INTO seq_id;

        SELECT FLOOR(EXTRACT(EPOCH FROM clock_timestamp()) * 1000) INTO now_millis;
        result := (now_millis - our_epoch) << 23;
        result := result | (shard_id << 10);
        result := result | (seq_id);
    END;
    $$ LANGUAGE PLPGSQL;

    CREATE TABLE users (
        id                  BIGINT          PRIMARY KEY DEFAULT get_id(),
        username            TEXT            NOT NULL    DEFAULT md5(random()::text),
        display_username    TEXT            NOT NULL    DEFAULT md5(random()::text),
        created_at          TIMESTAMPTZ     NOT NULL    DEFAULT now(),
        about               TEXT            NULL,
        google_id           TEXT            NULL,
        wikidot_uid         INTEGER         NULL
    );

    CREATE UNIQUE INDEX users_username_idx
        ON USERS (username);

    CREATE UNIQUE INDEX users_google_id_idx
        ON USERS (google_id);

    CREATE UNIQUE INDEX users_wikidot_uid_idx
        ON USERS (wikidot_uid);
`);

exports.down = (knex) =>
    knex.raw(`
    DROP TABLE users;
    DROP SEQUENCE counter_seq;
`);
