'use strict';

exports.up = (knex) =>
    knex.raw(`
    CREATE TABLE pages (
        id                  BIGINT          PRIMARY KEY     DEFAULT get_id(),
        name                TEXT            NOT NULL,
        branch_name         TEXT            NOT NULL        REFERENCES branches(name) ON DELETE CASCADE,
        created_at          TIMESTAMPTZ     NOT NULL,
        created_by_id       BIGINT          NOT NULL,
        updated_at          TIMESTAMPTZ     NOT NULL,
        updated_by_id       BIGINT          NOT NULL,

        current_revision_id BIGINT          NULL
    );

    CREATE UNIQUE INDEX pages_name_branch_name_idx
        ON pages (name, branch_name);


    CREATE TABLE page_revisions (
        id              BIGINT          PRIMARY KEY     DEFAULT get_id(),
        page_id         BIGINT          NOT NULL        REFERENCES pages(id) ON DELETE CASCADE,
        title           TEXT            NOT NULL,
        content         TEXT            NOT NULL,
        created_at      TIMESTAMPTZ     NOT NULL        DEFAULT now(),
        created_by_id   BIGINT          NOT NULL
    );

    CREATE INDEX page_revisions_page_id_idx
        ON page_revisions (page_id);


    CREATE TABLE tags (
        id              BIGINT      PRIMARY KEY         DEFAULT get_id(),
        branch_name     TEXT        NOT NULL            REFERENCES branches(name) ON DELETE CASCADE,
        name            TEXT        NOT NULL
    );

    CREATE UNIQUE INDEX tags_name_in_branches_idx
        ON tags (branch_name, name);


    CREATE TABLE pages_tags (
        tag_id      BIGINT  DEFAULT get_id()    REFERENCES tags(id)     ON DELETE CASCADE,
        page_id     BIGINT  NOT NULL            REFERENCES pages(id)    ON DELETE CASCADE,
        PRIMARY KEY (page_id, tag_id)
    );


    CREATE TABLE votes (
        id      BIGINT PRIMARY KEY  NOT NULL DEFAULT get_id(),
        value   INT                 NOT NULL DEFAULT 0,
        user_id BIGINT              NOT NULL REFERENCES users(id) ON DELETE CASCADE,
        page_id BIGINT              NOT NULL REFERENCES pages(id) ON DELETE CASCADE
    );

    CREATE UNIQUE INDEX votes_page_user_ids_uindex
        ON votes (page_id, user_id);
`);

exports.down = (knex) =>
    knex.raw(`
    DROP TABLE pages CASCADE;
    DROP TABLE votes CASCADE;
    DROP TABLE tags CASCADE;
    DROP TABLE page_revisions CASCADE;
    DROP TABLE pages_tags CASCADE;
`);
